#!/usr/bin/env bash

###################################
# Methods output check
# validates reconstructed dimension reduction
# meant to be run by the `process_*.sh` script of methods modules. 
###################################

function check_methods () {( set -e
  
  #1: DATASET
  local DATASET=$1
  shift

  
  ALL_DIMRED_REC=`ls data/${DATA_VARS['name']} | grep "^${DATASET}.*red_dim.mtx.gz$"`
  for DIMRED_REC in ${ALL_DIMRED_REC[@]}
    do
        echo "DOING FILE ${DIMRED_REC}"
        gunzip -c data/${DATA_VARS['name']}/$DIMRED_REC > data/${DATA_VARS['name']}/${DIMRED_REC%.gz}
        gunzip -c ${IN_PATH['count_file']}dim_red_${DATASET}.mtx.gz > ${IN_PATH['count_file']}dim_red_${DATASET}.mtx
        gunzip -c ${IN_PATH['count_file']}norm_counts_${DATASET}.mtx.gz > ${IN_PATH['count_file']}norm_counts_${DATASET}.mtx
        NCELLS_DIMRED_REC=`head -2 data/${DATA_VARS['name']}/${DIMRED_REC%.gz} | tail -1 | awk '//{print $1}' `
        NCELLS_DIMRED=`head -2 ${IN_PATH['count_file']}dim_red_${DATASET}.mtx | tail -1 | awk '//{print $1}' `
        NCELLS_NORM=`head -2 ${IN_PATH['count_file']}norm_counts_${DATASET}.mtx | tail -1 | awk '//{print $2}' `


        if [ "$NCELLS_DIMRED_REC" -ne "$NCELLS_DIMRED" ]
            then 
            echo "Error: number of cells in dim_red and reconstructed dim_red don't match for file ${DIMRED_REC}"
            exit 1
        fi

        if [ "$NCELLS_NORM" -ne "$NCELLS_DIMRED_REC" ]
            then 
            echo "Error: number of cells in reconstructed dim_red and norm_counts don't match for file ${DIMRED_REC}"
            exit 1
        fi

        rm data/${DATA_VARS['name']}/${DIMRED_REC%.gz}
        rm ${IN_PATH['count_file']}dim_red_${DATASET}.mtx
        rm ${IN_PATH['count_file']}norm_counts_${DATASET}.mtx
    done

)}
